@@ -13,7 +13,7 @@ class SwidgetDimmer(SwidgetDevice):
 
     def __init__(self, host,  token_name: str, secret_key: str, use_https: bool, use_websockets: bool) -> None:
         super().__init__(host=host, token_name=token_name, secret_key=secret_key, use_https=use_https, use_websockets=use_websockets)
-        self._device_type = "dimmer"
+        self._device_type = DeviceType.Dimmer
 
     @property  # type: ignore
     def brightness(self) -> int:
@@ -21,6 +21,7 @@ class SwidgetDimmer(SwidgetDevice):
 
         Will return a range between 0 - 100.
         """
+        _LOGGER.debug("SwidgetDimmer.brightness called")
         if not self.is_dimmable:
             raise SwidgetException("Device is not dimmable.")
         try:
@@ -28,15 +29,16 @@ class SwidgetDimmer(SwidgetDevice):
         except KeyError:
             return self.assemblies['host'].components["0"].functions["level"]["default"]
 
-    async def set_brightness(self, brightness):
+    async def set_brightness(self, brightness) -> None:
         """Set the brightness of the device."""
-        _LOGGER.debug("SwidgetDimmer.set_brightness() called")
+        _LOGGER.debug("SwidgetDimmer.set_brightness() called with brightness: {brightness}")
+        self.assemblies['host'].components["0"].functions["level"]["now"] = brightness
         await self.send_command(
             assembly="host", component="0", function="level", command={"now": brightness}
         )
 
-    async def set_default_brightness(self, brightness):
-        _LOGGER.debug("SwidgetDimmer.set_default_brightness() called")
+    async def set_default_brightness(self, brightness) -> None:
+        _LOGGER.debug("SwidgetDimmer.set_default_brightness() called with brightness: {brightness}")
         await self.send_command(
             assembly="host", component="0", function="level", command={"default": brightness}
         )
@@ -44,4 +46,5 @@ class SwidgetDimmer(SwidgetDevice):
     @property  # type: ignore
     def is_dimmable(self) -> bool:
         """Whether the switch supports brightness changes."""
+        _LOGGER.debug("SwidgetDimmer.is_dimmable() called")
         return True
\ No newline at end of file
